@@ -2,7 +2,7 @@
 #  SPDX-License-Identifier: Apache-2.0
 import luigi
 
-from servicecatalog_puppet import utils
+from servicecatalog_puppet import constants, utils
 from servicecatalog_puppet.workflow.dependencies import tasks
 
 
@@ -11,6 +11,7 @@ class TerminateAssociationsForSpokeLocalPortfolioTask(tasks.TaskWithReference):
     region = luigi.Parameter()
     portfolio = luigi.Parameter()
     spoke_local_portfolio_name = luigi.Parameter()
+    cachable_level = constants.CACHE_LEVEL_NORMAL
 
     def params_for_results_display(self):
         return {
@@ -19,7 +20,6 @@ class TerminateAssociationsForSpokeLocalPortfolioTask(tasks.TaskWithReference):
             "spoke_local_portfolio_name": self.spoke_local_portfolio_name,
             "region": self.region,
             "account_id": self.account_id,
-            "cache_invalidator": self.cache_invalidator,
         }
 
     def run(self):
