@@ -7,8 +7,7 @@ import luigi
 import troposphere as t
 from troposphere import servicecatalog
 
-from servicecatalog_puppet import config
-from servicecatalog_puppet import utils
+from servicecatalog_puppet import config, constants, utils
 from servicecatalog_puppet.workflow.dependencies import tasks
 
 
@@ -21,6 +20,7 @@ class CreateLaunchRoleConstraintsForSpokeLocalPortfolioTask(tasks.TaskWithRefere
     launch_constraints = luigi.ListParameter()
 
     portfolio_get_all_products_and_their_versions_ref = luigi.Parameter()
+    cachable_level = constants.CACHE_LEVEL_NORMAL
 
     def params_for_results_display(self):
         return {
@@ -29,7 +29,6 @@ class CreateLaunchRoleConstraintsForSpokeLocalPortfolioTask(tasks.TaskWithRefere
             "portfolio": self.portfolio,
             "region": self.region,
             "account_id": self.account_id,
-            "cache_invalidator": self.cache_invalidator,
         }
 
     def run(self):
